@@ -22,30 +22,8 @@
 
 #include "gtkshell.h"
 
-unsigned int gsh_rows=8;
-unsigned int gsh_row=1;
-
-void
-gsh_new_row()
-{
- gsh_vbox = gtk_vbox_new(FALSE, 2);
- gtk_container_add(GTK_CONTAINER(gsh_hbox), gsh_vbox);
- gtk_widget_show(gsh_vbox);
- gsh_row = 1;
-}
-
-void
-gsh_check_row()
-{
-#ifdef DEBUG
- printf("==> gsh_row: %d, gsh_rows: %d\n", gsh_row, gsh_rows);
-#endif
-
- if(gsh_row > gsh_rows)
- {
-  gsh_new_row();
- }
-}
+extern unsigned int gsh_rows;
+extern unsigned int gsh_row;
 
 void
 gsh_parse_arguments(int argc, char **argv)
