@@ -27,28 +27,28 @@ gboolean gsh_button_exits=FALSE;
 void
 gsh_test_exit()
 {
- if (gsh_button_exits == TRUE)
- {
-  exit(0);
- }
+	if (gsh_button_exits)
+		exit(0);
 }
 
 void
 system_cb(GtkWidget * widget, gpointer data)
 {
- antiright_system(data);
- gsh_test_exit();
-	widget=NULL;
+	UNUSED(widget);
+
+	antiright_system(data);
+	gsh_test_exit();
 }
 
 void
 entry_cb(GtkWidget * widget, gpointer data)
 {
- gchar          *command;
- const gchar    *input;
- input = gtk_entry_get_text(GTK_ENTRY(widget));
- asprintf(&command, "%s %s", (char *) data, (char *) input);
- antiright_system(command);
- free(command);
- gsh_test_exit();
+	gchar          *command;
+	const gchar    *input;
+
+	input = gtk_entry_get_text(GTK_ENTRY(widget));
+	asprintf(&command, "%s %s", (char *) data, (char *) input);
+	system_cb(NULL, command);
+	free(command);
 }
+
