@@ -22,18 +22,51 @@
 
 #include "gtkshell.h"
 
-extern unsigned int gsh_rows;
-extern unsigned int gsh_row;
+extern char *gsh_geometry;
 
 void
-gsh_manage(GtkWidget *widget)
+gsh_set_geometry()
 {
- gsh_check_row();
- gtk_container_add(GTK_CONTAINER(gsh_vbox), widget);
- gtk_widget_show(widget);
- gsh_row++;
-#ifdef DEBUG
- printf("gsh_row: %d, gsh_rows: %d\n", gsh_row, gsh_rows);
-#endif
+	assert(gsh_geometry);
+	gtk_window_parse_geometry(GTK_WINDOW(gsh_window), 
+		gsh_geometry);
+}
+void
+gsh_check_and_set_geometry()
+{
+	if(gsh_geometry!=NULL)
+	{	
+		gsh_set_geometry();
+		free(gsh_geometry);
+	}
+	else
+	{
+		asprintf(&gsh_geometry, "500x300");
+		gsh_set_geometry();
+		free(gsh_geometry);
+	}
+
+}
+
+GtkWidget *
+gsh_create_main_window()
+{
+	GtkWidget *window;
+
+	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+
+	g_signal_connect (window, "delete-event",
+		G_CALLBACK (gtk_main_quit), NULL);
+  	g_signal_connect (window, "destroy",
+		G_CALLBACK (gtk_main_quit), NULL); 
+
+	return(window);		
+}
+
+void
+gsh_init(int *argc, char ***argv)
+{
+	gtk_init(argc, argv);
+	gsh_window=gsh_create_main_window();
 }
 
