@@ -40,6 +40,8 @@
 #include "add_options.h"
 #include "dialog_options.h"
 #include "file_dialog.h"
+#include "row.h"
+#include "containers.h"
 
 GtkWidget      *gsh_window;
 GtkWidget      *gsh_hbox;
@@ -48,7 +50,16 @@ GtkWidget      *gsh_label;
 
 
 void
-gsh_manage(GtkWidget *widget);
+gsh_init(int *argc, char ***argv);
 
+void
+gsh_set_geometry();
+
+void
+gsh_check_and_set_geometry();
+
+GtkWidget *
+gsh_create_main_window();
 
 #endif
+
