@@ -34,7 +34,7 @@ gsh_add_label(char *text)
 void
 gsh_set_label(GtkWidget *label, char *text)
 {
-	char *markup;
+	gchar *markup;
 	
 	markup=g_markup_printf_escaped
 		("<span size=\"small\"><tt>%s</tt></span>", text);
