@@ -50,6 +50,10 @@ gsh_handle_switch_arguments(int argc, char **argv, unsigned int *counter)
 				argv, 
 				counter);
 			break;
+        case 'h':
+            g_printerr("Read the source code.\n");
+            exit(1);
+            break;
 		case 'o':
 			gsh_handle_option_arguments(
 				argc, 
@@ -57,7 +61,7 @@ gsh_handle_switch_arguments(int argc, char **argv, unsigned int *counter)
 				counter);
 			break;
 		default:
-			printf("%s:  undefined\n", argv[(*counter)]);
+			g_printerr("%s:  undefined\n", argv[(*counter)]);
 			break;
 	}
 }
