@@ -26,6 +26,6 @@ void
 gsh_count(int argc, int *counter);
 
 void
-gsh_handle_options(int argc, char **argv, unsigned int *counter);
+gsh_handle_switch_arguments(int argc, char **argv, unsigned int *counter);
 
 #endif
