@@ -40,7 +40,7 @@ gsh_setup_prompt_command_entry(char *command)
 	GtkWidget *entry;
 	entry=gsh_setup_command_entry(command);
 	g_signal_connect(G_OBJECT(entry), "activate", 
-		G_CALLBACK(gtk_main_quit), (gpointer) command);
+		G_CALLBACK(gtk_main_quit), NULL);
 }
 
 void
