@@ -22,6 +22,18 @@
 
 #include "gtkshell.h"
 
+void
+gsh_check_results(char **results)
+{
+    /* This ensures that the result string is not empty, avoiding certain formatting problems.  */
+    /* Otherwise, a GTK warning is produced.  */
+    if(!strncmp(*results, "", 1))
+    {
+        free(*results);
+        asprintf(results, " ");
+    }
+}
+
 void
 gsh_update_label(char *command, void *widget)
 {
@@ -30,8 +42,11 @@ gsh_update_label(char *command, void *widget)
 #ifdef DEBUG
 	puts("gsh_update_label()");
 #endif
-	
+
 	results=antiright_pipe_read(command);
+
+    gsh_check_results(&results);
+
 	gsh_set_label((GtkWidget*)widget, results);
 	free(results);
 }
@@ -46,6 +61,6 @@ gsh_add_updated_label(char *command)
 #endif
 	widget=gtk_label_new("");
 	gsh_manage(widget);
-	gsh_add_update(&gsh_update_label, command, (void*)widget);
+	gsh_add_updater(&gsh_update_label, command, (void*)widget);
 }
 
