@@ -22,18 +22,26 @@
 
 #include "gtkshell.h"
 
-extern gboolean gsh_updater_defined;
+extern GSList *gsh_updater_list;
+gboolean gsh_is_updating=FALSE;
 
 void
 gsh_test_updating()
 {
-	if(gsh_updater_defined==FALSE)      
+	if(!gsh_is_updating)
         {
-        	gsh_start_updates();
-        	gsh_updater_defined=TRUE;
+            gsh_start_updates();
+		    gsh_is_updating=TRUE;
         }
 }
 
+void
+gsh_updater_argument_generic(int argc, unsigned int *counter)
+{
+    gsh_count(argc, counter);
+    gsh_test_updating();
+}
+
 void
 gsh_handle_updated_arguments(int argc, char **argv, unsigned int *counter)
 {
@@ -41,14 +49,12 @@ gsh_handle_updated_arguments(int argc, char **argv, unsigned int *counter)
 	switch(argv[(*counter)][3])
 	{
 		case 'l':
-			gsh_count(argc, counter);
-   			gsh_add_updated_label(argv[*counter]);
-			gsh_test_updating();
+			gsh_add_updated_label(argv[*counter+1]);
+            gsh_updater_argument_generic(argc, counter);
 			break;
 		case 'p':
-			gsh_count(argc, counter);
-        		gsh_add_updated_progress(argv[*counter]);
-			gsh_test_updating();
+            gsh_add_updated_progress(argv[*counter+1]);
+            gsh_updater_argument_generic(argc, counter);
 			break;
 	}
 }
