@@ -37,6 +37,6 @@ gsh_add_updated_progress(char *command)
 	GtkWidget *widget;
 	widget=gtk_progress_bar_new();
 	gsh_manage(widget);
-	gsh_add_update(&gsh_update_progress, command, (void*)widget);
+	gsh_add_updater(&gsh_update_progress, command, (void*)widget);
 }
 
