@@ -1,9 +1,8 @@
-
 /*
   AntiRight
-  (c) 2002-2006 Jeffrey Bedard
+  (c) 2002-2007 Jeffrey Bedard
   antiright@gmail.com
- 
+
   This file is part of AntiRight.
 
   AntiRight is free software; you can redistribute it and/or modify
@@ -28,6 +27,8 @@
 #include <stdio.h>
 #include <string.h>
 #include <assert.h>
+#include <stdarg.h>
+#include <glib.h>
 
 #include "pipe.h"
 #include "string.h"
