@@ -25,9 +25,9 @@
 void *
 xmalloc(size_t size)
 {
-  void *pointer;
-  pointer=malloc(size);
-  assert(pointer != NULL); /* Ensure that the allocation was
+  gpointer pointer;
+  pointer=g_malloc(size);
+  assert(pointer); /* Ensure that the allocation was
 			      successful.  */
   return(pointer);
 }
