@@ -24,8 +24,8 @@
 #define LIBAR_UTIL_H
 void *
 xmalloc(size_t size);
-/* char *  */
-/* antiright_get_file_extension(char *filename); */
+
+#define UNUSED(arg) { arg = arg; }
 
 #endif
 
